#######################################################################################
    # This script consist of the estimation of real and nominal house prices 
    # House price and CPI are extracted from the cited references in Norges Bank (2023a)
    # and Norges Bank (n.d.-a) to the file denoted in the read_excel.
    # For this estimation, use the file: "Dataset_Houseprice and CPI"
#######################################################################################

# Packages
library(rmarkdown)  # to generate pdf file
library(tinytex)    # to generate pdf file
library(readxl)     # to read Excel files
library(ggplot2)    # plot time series 

# Working directory
setwd("~/Desktop/Koding")

# Import data from Excel file
data <- read_excel("/Users/piaegeberg/Desktop/Koding/Dataset_Houseprice and CPI .xls")
data <- as.data.frame(data)

# Making sure Year is denoted as date 
data$Year <- as.Date(data$Year, format = "%m/%d/%Y")
data$Year <- as.Date(data$Year)

#######################################################################################

## Calculating real house price
data$realhouseprice <- (data$Prices/data$CPI)

## Making new variables (log and diff)
data$logrealprice <- log(data$realhouseprice)
data$logprice <- log(data$Prices)
data$diffprice <- c( NA, diff(data$logprice))  


## Plotting nominal log prices
plot(data$Year, data$logprice,
     ylab="",
     ylim = c(2,10.5),
     xaxt = "n",
     xlab="",
     type="l",
     col="blue")
grid()
axis(side = 1, at = seq(min(data$Year), max(data$Year), by = "7 years"), labels = format(seq(min(data$Year), max(data$Year), by = "7 years"), "%Y"))
legend("bottomright", legend = c("Nominal house price"), 
       col = c("blue"), lty = 1, cex = 0.67)

## Plotting real log prices
plot(data$Year, data$logrealprice,
     ylab="",
     ylim = c(2,6),
     xaxt = "n",
     xlab="",
     type="l",
     col="red")
grid()
axis(side = 1, at = seq(min(data$Year), max(data$Year), by = "7 years"), labels = format(seq(min(data$Year), max(data$Year), by = "7 years"), "%Y"))
legend("bottomright", legend = c("Real house price"), 
       col = c("red"), lty = 1, cex = 0.67)

#######################################################################################

## Plotting nominal log prices and differenced prices
par(mfrow   = c(1,2), 
    pty     = "s",
    las     = 0,
    family  = "serif")
plot(data$Year, data$logprice,
     ylab="",
     ylim = c(2,10.5),
     xaxt = "n",
     xlab="",
     type="l",
     col="blue")
grid()
axis(side = 1, at = seq(min(data$Year), max(data$Year), by = "5 years"), labels = format(seq(min(data$Year), max(data$Year), by = "5 years"), "%Y"))
legend("bottomright", legend = c("(log) Nominal house price"), 
       col = c("blue"), lty = 1, cex = 0.67)
plot(data$Year, data$diffprice,
     ylab="",
     xaxt = "n",
     xlab="",
     type="l",
     col="blue")
grid()
axis(side = 1, at = seq(min(data$Year), max(data$Year), by = "5 years"), labels = format(seq(min(data$Year), max(data$Year), by = "5 years"), "%Y"))
legend("bottomright", legend = c("(log) Differneced nominal house price"), 
       col = c("blue"), lty = 1, cex = 0.67)

